Dyff 0.5.1 release
==================

- Fix invalid query key ``name`` for evaluations.

- Fix ``run_report`` skipping dataset directories that begin with underscore
  (``_``).

- Update ``GetResumeScore`` rubric to accommodate ``_replication_`` and
  robustify regex matching.
